@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2019 The pyXem developers
+# Copyright 2018-2020 the orix developers
 #
 # This file is part of orix.
 #
@@ -16,4 +16,16 @@
 # You should have received a copy of the GNU General Public License
 # along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
-from .rotation_plot import RodriguesPlot
+"""Plotting of various objects."""
+
+from orix.plot.crystal_map_plot import convert_unit, CrystalMapPlot
+from orix.plot.rotation_plot import AxAnglePlot, RodriguesPlot, RotationPlot
+
+# Lists what will be imported when calling "from orix.plot import *"
+__all__ = [
+    "convert_unit",
+    "CrystalMapPlot",
+    "AxAnglePlot",
+    "RodriguesPlot",
+    "RotationPlot",
+]
