@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2019 The pyXem developers
+# Copyright 2018-2020 the orix developers
 #
 # This file is part of orix.
 #
@@ -48,6 +48,8 @@ from orix.quaternion import Quaternion
 from orix.vector import Vector3d
 from orix.scalar import Scalar
 
+_FLOAT_EPS = np.finfo(np.float).eps  # Used to round values below 1e-16 to zero
+
 
 class Rotation(Quaternion):
     """Rotation object.
@@ -326,10 +328,15 @@ class Rotation(Quaternion):
         euler : array-like
             Euler angles in the Bunge convention.
         convention : str
-            Only 'bunge' is currently suppported for new data
+            Only 'bunge' is currently supported for new data
         direction : str
             'lab2crystal' or 'crystal2lab'
         """
+        if convention not in ["bunge", "Krakow_Hielscher"]:
+            raise ValueError("The chosen convention is not one of the allowed options")
+        if direction not in ["lab2crystal", "crystal2lab"]:
+            raise ValueError("The chosen direction is not one of the allowed options")
+
         if convention == "Krakow_Hielscher":
             # To be applied to the data found at:
             # https://www.repository.cam.ac.uk/handle/1810/263510
@@ -349,47 +356,138 @@ class Rotation(Quaternion):
                 np.stack((np.cos(gamma / 2), zero, zero, np.sin(gamma / 2)), axis=-1)
             )
             data = qalpha * qbeta * qgamma
+
             rot = cls(data.data)
             rot.improper = zero
             return rot
 
-        if convention != "bunge":
-            raise ValuerError("Only 'bunge' is an acceptable convention")
-        if direction not in ["lab2crystal", "crystal2lab"]:
-            raise ValueError("The chosen direction is not one of the allowed options")
+        elif convention == "bunge":
+            euler = np.array(euler)
+            n = euler.shape[:-1]
 
-        euler = np.array(euler)
-        n = euler.shape[:-1]
+            # Uses A.5 & A.6 from Modelling Simul. Mater. Sci. Eng. 23 (2015) 083501
 
-        # Uses A.5 & A.6 from Modelling Simul. Mater. Sci. Eng. 23 (2015) 083501
+            alpha = euler[..., 0]  # psi1
+            beta = euler[..., 1]  # Psi
+            gamma = euler[..., 2]  # psi3
 
-        alpha = euler[..., 0]  # psi1
-        beta = euler[..., 1]  # Psi
-        gamma = euler[..., 2]  # psi3
+            sigma = 0.5 * np.add(alpha, gamma)
+            delta = 0.5 * np.subtract(alpha, gamma)
+            c = np.cos(beta / 2)
+            s = np.sin(beta / 2)
 
-        sigma = 0.5 * np.add(alpha, gamma)
-        delta = 0.5 * np.subtract(alpha, gamma)
-        c = np.cos(beta / 2)
-        s = np.sin(beta / 2)
+            # Using P = 1 from A.6
+            q = np.zeros(n + (4,))
+            q[..., 0] = c * np.cos(sigma)
+            q[..., 1] = -s * np.cos(delta)
+            q[..., 2] = -s * np.sin(delta)
+            q[..., 3] = -c * np.sin(sigma)
 
-        # Using P = 1 from A.6
+            for i in [1, 2, 3, 0]:  # flip the zero element last
+                q[..., i] = np.where(q[..., 0] < 0, -q[..., i], q[..., i])
+
+            data = Quaternion(q)
+
+            if direction == "lab2crystal":
+                data = ~data
+
+            rot = cls(data.data)
+            rot.improper = np.zeros((n))
+            return rot
+
+    def to_matrix(self):
+        """Rotations as orientation matrices [Rowenhorst2015]_.
+
+        Returns
+        -------
+        ndarray
+            Array of orientation matrices.
+
+        References
+        ----------
+        .. [Rowenhorst2015] D. Rowenhorst, A. D. Rollett, G. S. Rohrer, M.
+            Groeber, M. Jackson, P. J. Konijnenberg, M. De Graef,
+            "Consistent representations of and conversions between 3D
+            rotations," *Modelling and Simulation in Materials Science and
+            Engineering* **23** (2015), doi:
+            https://doi.org/10.1088/0965-0393/23/8/083501
+
+        Examples
+        --------
+        >>> import numpy as np
+        >>> from orix.quaternion.rotation import Rotation
+        >>> r = Rotation([1, 0, 0, 0])
+        >>> np.allclose(r.to_matrix(), np.eye(3))
+        True
+        >>> r = Rotation([0, 1, 0, 0])
+        >>> np.allclose(r.to_matrix(), np.diag([1, -1, -1]))
+        True
+        """
+        a, b, c, d = self.a.data, self.b.data, self.c.data, self.d.data
+        om = np.zeros(self.shape + (3, 3))
+
+        bb = b ** 2
+        cc = c ** 2
+        dd = d ** 2
+        qq = a ** 2 - (bb + cc + dd)
+        bc = b * c
+        ad = a * d
+        bd = b * d
+        ac = a * c
+        cd = c * d
+        ab = a * b
+        om[..., 0, 0] = qq + 2 * bb
+        om[..., 0, 1] = 2 * (bc - ad)
+        om[..., 0, 2] = 2 * (bd + ac)
+        om[..., 1, 0] = 2 * (bc + ad)
+        om[..., 1, 1] = qq + 2 * cc
+        om[..., 1, 2] = 2 * (cd - ab)
+        om[..., 2, 0] = 2 * (bd - ac)
+        om[..., 2, 1] = 2 * (cd + ab)
+        om[..., 2, 2] = qq + 2 * dd
+
+        return om
+
+    @classmethod
+    def from_matrix(cls, matrix):
+        """Creates rotations from orientation matrices [Rowenhorst2015]_.
+
+        Parameters
+        ----------
+        matrix : array_like
+            Array of orientation matrices.
+
+        Examples
+        --------
+        >>> import numpy as np
+        >>> from orix.quaternion.rotation import Rotation
+        >>> r = Rotation.from_matrix(np.eye(3))
+        >>> np.allclose(r.data, [1, 0, 0, 0])
+        True
+        >>> r = Rotation.from_matrix(np.diag([1, -1, -1]))
+        >>> np.allclose(r.data, [0, 1, 0, 0])
+        True
+        """
+        om = np.asarray(matrix)
+        n = (1,) if om.ndim == 2 else om.shape[:-2]  # Assuming (3, 3) as last two dims
         q = np.zeros(n + (4,))
-        q[..., 0] = c * np.cos(sigma)
-        q[..., 1] = -s * np.cos(delta)
-        q[..., 2] = -s * np.sin(delta)
-        q[..., 3] = -c * np.sin(sigma)
 
-        for i in [1, 2, 3, 0]:  # flip the zero element last
-            q[..., i] = np.where(q[..., 0] < 0, -q[..., i], q[..., i])
+        # Compute quaternion components
+        q0_almost = 1 + om[..., 0, 0] + om[..., 1, 1] + om[..., 2, 2]
+        q1_almost = 1 + om[..., 0, 0] - om[..., 1, 1] - om[..., 2, 2]
+        q2_almost = 1 - om[..., 0, 0] + om[..., 1, 1] - om[..., 2, 2]
+        q3_almost = 1 - om[..., 0, 0] - om[..., 1, 1] + om[..., 2, 2]
+        q[..., 0] = 0.5 * np.sqrt(np.where(q0_almost < _FLOAT_EPS, 0, q0_almost))
+        q[..., 1] = 0.5 * np.sqrt(np.where(q1_almost < _FLOAT_EPS, 0, q1_almost))
+        q[..., 2] = 0.5 * np.sqrt(np.where(q2_almost < _FLOAT_EPS, 0, q2_almost))
+        q[..., 3] = 0.5 * np.sqrt(np.where(q3_almost < _FLOAT_EPS, 0, q3_almost))
 
-        data = Quaternion(q)
+        # Modify component signs if necessary
+        q[..., 1] = np.where(om[..., 2, 1] < om[..., 1, 2], -q[..., 1], q[..., 1])
+        q[..., 2] = np.where(om[..., 0, 2] < om[..., 2, 0], -q[..., 2], q[..., 2])
+        q[..., 3] = np.where(om[..., 1, 0] < om[..., 0, 1], -q[..., 3], q[..., 3])
 
-        if direction == "lab2crystal":
-            data = ~data
-
-        rot = cls(data.data)
-        rot.improper = np.zeros((n))
-        return rot
+        return cls(Quaternion(q)).unit  # Normalized
 
     @classmethod
     def identity(cls, shape=(1,)):
