@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2019 The pyXem developers
+# Copyright 2018-2020 the orix developers
 #
 # This file is part of orix.
 #
@@ -21,10 +21,14 @@
 As well as themselves representing physical quantities, Scalars
 may represent elements of higher-dimensional quantities, such as the x-component
 of a vector or the rotation angle of a quaternion.
-
 """
+
 import numpy as np
-from orix.base import Object3d, DimensionError
+
+from orix.base import Object3d
+
+
+__all__ = ["Scalar"]
 
 
 class Scalar(Object3d):
